@@ -2,25 +2,16 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2021 Nicolargo <nicolas@nicolargo.com>
+# SPDX-FileCopyrightText: 2022 Nicolas Hennion <nicolas@nicolargo.com>
 #
-# Glances is free software; you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# SPDX-License-Identifier: LGPL-3.0-only
 #
-# Glances is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 """CPU percent stats shared between CPU and Quicklook plugins."""
 
 from glances.logger import logger
 from glances.timer import Timer
+from glances.compat import FileNotFoundError, PermissionError
 
 import psutil
 
@@ -30,11 +21,7 @@ class CpuPercent(object):
     """Get and store the CPU percent."""
 
     def __init__(self, cached_timer_cpu=3):
-        self.cpu_info = {
-            'cpu_name': None,
-            'cpu_hz_current': None,
-            'cpu_hz': None
-        }
+        self.cpu_info = {'cpu_name': None, 'cpu_hz_current': None, 'cpu_hz': None}
         self.cpu_percent = 0
         self.percpu_percent = []
 
@@ -65,7 +52,7 @@ class CpuPercent(object):
             return self.__get_cpu()
 
     def get_info(self):
-        """Get additional informations about the CPU"""
+        """Get additional information about the CPU"""
         # Never update more than 1 time per cached_timer_cpu_info
         if self.timer_cpu_info.finished() and hasattr(psutil, 'cpu_freq'):
             # Get the CPU freq current/max
@@ -91,7 +78,7 @@ class CpuPercent(object):
         # @TODO: Multisystem...
         try:
             self.cpu_info['cpu_name'] = open('/proc/cpuinfo', 'r').readlines()[4].split(':')[1].strip()
-        except:
+        except (FileNotFoundError, PermissionError, IndexError, KeyError, AttributeError):
             self.cpu_info['cpu_name'] = 'CPU'
         return self.cpu_info['cpu_name']
 
@@ -109,14 +96,15 @@ class CpuPercent(object):
         # Never update more than 1 time per cached_timer_cpu
         if self.timer_percpu.finished():
             self.percpu_percent = []
-            for cpu_number, cputimes in enumerate(psutil.cpu_times_percent(interval=0.0,
-                                                                           percpu=True)):
-                cpu = {'key': self.get_key(),
-                       'cpu_number': cpu_number,
-                       'total': round(100 - cputimes.idle, 1),
-                       'user': cputimes.user,
-                       'system': cputimes.system,
-                       'idle': cputimes.idle}
+            for cpu_number, cputimes in enumerate(psutil.cpu_times_percent(interval=0.0, percpu=True)):
+                cpu = {
+                    'key': self.get_key(),
+                    'cpu_number': cpu_number,
+                    'total': round(100 - cputimes.idle, 1),
+                    'user': cputimes.user,
+                    'system': cputimes.system,
+                    'idle': cputimes.idle,
+                }
                 # The following stats are for API purposes only
                 if hasattr(cputimes, 'nice'):
                     cpu['nice'] = cputimes.nice
