@@ -2,7 +2,7 @@
 #
 # This file is part of Glances.
 #
-# SPDX-FileCopyrightText: 2022 Nicolas Hennion <nicolas@nicolargo.com>
+# SPDX-FileCopyrightText: 2023 Nicolas Hennion <nicolas@nicolargo.com>
 #
 # SPDX-License-Identifier: LGPL-3.0-only
 #
@@ -57,7 +57,7 @@ class _GlancesCurses(object):
         'c': {'sort_key': 'cpu_percent'},
         'C': {'switch': 'disable_cloud'},
         'd': {'switch': 'disable_diskio'},
-        'D': {'switch': 'disable_docker'},
+        'D': {'switch': 'disable_containers'},
         # 'e' > Enable/Disable process extended
         # 'E' > Erase the process filter
         # 'f' > Show/hide fs / folder stats
@@ -124,7 +124,7 @@ class _GlancesCurses(object):
     _left_sidebar_max_width = 34
 
     # Define right sidebar
-    _right_sidebar = ['docker', 'processcount', 'amps', 'processlist', 'alert']
+    _right_sidebar = ['containers', 'processcount', 'amps', 'processlist', 'alert']
 
     def __init__(self, config=None, args=None):
         # Init
@@ -268,6 +268,7 @@ class _GlancesCurses(object):
             self.ifCAREFUL_color2 = curses.color_pair(8) | A_BOLD
             self.ifWARNING_color2 = curses.color_pair(5) | A_BOLD
             self.ifCRITICAL_color2 = curses.color_pair(6) | A_BOLD
+            self.ifINFO_color = curses.color_pair(8)
             self.filter_color = A_BOLD
             self.selected_color = A_BOLD
 
@@ -301,6 +302,7 @@ class _GlancesCurses(object):
             self.ifCAREFUL_color2 = curses.A_UNDERLINE
             self.ifWARNING_color2 = A_BOLD
             self.ifCRITICAL_color2 = curses.A_REVERSE
+            self.ifINFO_color = A_BOLD
             self.filter_color = A_BOLD
             self.selected_color = A_BOLD
 
@@ -328,6 +330,7 @@ class _GlancesCurses(object):
             'CRITICAL_LOG': self.ifCRITICAL_color,
             'PASSWORD': curses.A_PROTECT,
             'SELECTED': self.selected_color,
+            'INFO': self.ifINFO_color,
         }
 
     def set_cursor(self, value):
@@ -407,13 +410,15 @@ class _GlancesCurses(object):
         elif self.pressedkey == ord('9'):
             # '9' > Theme from black to white and reverse
             self._init_colors()
-        elif self.pressedkey == ord('e'):
+        elif self.pressedkey == ord('e') and not self.args.programs:
             # 'e' > Enable/Disable process extended
             self.args.enable_process_extended = not self.args.enable_process_extended
             if not self.args.enable_process_extended:
                 glances_processes.disable_extended()
             else:
                 glances_processes.enable_extended()
+            # When a process is selected (and only in standalone mode), disable the cursor
+            self.args.disable_cursor = self.args.enable_process_extended and self.args.is_standalone
         elif self.pressedkey == ord('E'):
             # 'E' > Erase the process filter
             glances_processes.process_filter = None
@@ -427,7 +432,7 @@ class _GlancesCurses(object):
         elif self.pressedkey == ord('-'):
             # '+' > Decrease process nice level
             self.decrease_nice_process = not self.decrease_nice_process
-        elif self.pressedkey == ord('k'):
+        elif self.pressedkey == ord('k') and not self.args.disable_cursor:
             # 'k' > Kill selected process (after confirmation)
             self.kill_process = not self.kill_process
         elif self.pressedkey == ord('w'):
@@ -451,11 +456,11 @@ class _GlancesCurses(object):
             # ">" (right arrow) navigation through process sort
             next_sort = (self.loop_position() + 1) % len(self._sort_loop)
             glances_processes.set_sort_key(self._sort_loop[next_sort], False)
-        elif self.pressedkey == curses.KEY_UP or self.pressedkey == 65:
+        elif self.pressedkey == curses.KEY_UP or self.pressedkey == 65 and not self.args.disable_cursor:
             # 'UP' > Up in the server list
             if self.args.cursor_position > 0:
                 self.args.cursor_position -= 1
-        elif self.pressedkey == curses.KEY_DOWN or self.pressedkey == 66:
+        elif self.pressedkey == curses.KEY_DOWN or self.pressedkey == 66 and not self.args.disable_cursor:
             # 'DOWN' > Down in the server list
             # if self.args.cursor_position < glances_processes.max_processes - 2:
             if self.args.cursor_position < glances_processes.processes_count:
@@ -612,7 +617,7 @@ class _GlancesCurses(object):
         max_processes_displayed = (
             self.term_window.getmaxyx()[0]
             - 11
-            - (0 if 'docker' not in __stat_display else self.get_stats_display_height(__stat_display["docker"]))
+            - (0 if 'containers' not in __stat_display else self.get_stats_display_height(__stat_display["containers"]))
             - (
                 0
                 if 'processcount' not in __stat_display
@@ -713,7 +718,11 @@ class _GlancesCurses(object):
 
         # Display graph generation popup
         if self.args.generate_graph:
-            self.display_popup('Generate graph in {}'.format(self.args.export_graph_path))
+            if 'graph' in stats.getExportsList():
+                self.display_popup('Generate graph in {}'.format(self.args.export_graph_path))
+            else:
+                logger.warning('Graph export module is disable. Run Glances with --export graph to enable it.')
+                self.args.generate_graph = False
 
         return True
 
@@ -1057,7 +1066,7 @@ class _GlancesCurses(object):
                     # Return to the first column
                     x = display_x
                     continue
-            except:
+            except Exception:
                 # Avoid exception (see issue #1692)
                 pass
             # Do not display outside the screen
